@@ -721,9 +721,14 @@ def init_translator(localedir, domain='all', langs=None):
     else:
         cur_locale, encoding = locale.getdefaultlocale()
         cur_langs = [cur_locale] if cur_locale else ['en']
-    translator = gettext.translation(domain, localedir=localedir, languages=cur_langs)
-    translator.install()
-    return translator.gettext
+    try:
+        translator = gettext.translation(domain, localedir=localedir, languages=cur_langs)
+        translator.install()
+        trans = translator.gettext
+    except FileNotFoundError as e:
+        print(f'No translation files found for domain: {domain}. Ignore this message if called for the first time.')
+        trans = str
+    return trans
 
 
 def match_files_except_lines(file1, file2, excluded=None):
@@ -732,8 +737,9 @@ def match_files_except_lines(file1, file2, excluded=None):
     with open(file2) as fp:
         content2 = fp.readlines()
     if excluded:
-        content1 = [cont for c, cont in enumerated(content1) if c not in excluded]
-        content2 = [cont for c, cont in enumerated(content2) if c not in excluded]
+        excluded = [excluded] if type(excluded).__name__ == 'int' else excluded
+        content1 = [cont for c, cont in enumerate(content1) if c not in excluded]
+        content2 = [cont for c, cont in enumerate(content2) if c not in excluded]
     return content1 == content2
 
 
